beobench.installer
==================

.. automodule:: beobench.installer

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      install_boptest
   
   

   
   
   

   
   
   



